@@ -13,5 +13,5 @@ import source
 
 from layer import LayerStack, Layer
 from source import Source
-from solver import RCWASolver as Solver
+from solver import Solver
 from plotter import Plotter
